AndroidVolumeDirection class

An enum of volume direction controls on Android.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
The index for this enum value.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

lower → AndroidVolumeDirection
Lower the ringer volume.
final
raise → AndroidVolumeDirection
Raise the ringer volume.
final
same → AndroidVolumeDirection
Keep the previous ringer volume.
final
values → Map<int, AndroidVolumeDirection>
A map of indices to values.
final